@@ -939,7 +939,8 @@ class NginxConfigurator(common.Installer):
                 [self.conf('ctl'), "-c", self.nginx_conf, "-V"],
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE,
-                universal_newlines=True)
+                universal_newlines=True,
+                env=util.env_no_snap_for_external_calls())
             text = proc.communicate()[1]  # nginx prints output to stderr
         except (OSError, ValueError) as error:
             logger.debug(str(error), exc_info=True)
@@ -1169,7 +1170,8 @@ def nginx_restart(nginx_ctl, nginx_conf):
 
     """
     try:
-        proc = subprocess.Popen([nginx_ctl, "-c", nginx_conf, "-s", "reload"])
+        proc = subprocess.Popen([nginx_ctl, "-c", nginx_conf, "-s", "reload"],
+                                env=util.env_no_snap_for_external_calls())
         proc.communicate()
 
         if proc.returncode != 0:
@@ -1179,7 +1181,7 @@ def nginx_restart(nginx_ctl, nginx_conf):
             with tempfile.TemporaryFile() as out:
                 with tempfile.TemporaryFile() as err:
                     nginx_proc = subprocess.Popen([nginx_ctl, "-c", nginx_conf],
-                        stdout=out, stderr=err)
+                        stdout=out, stderr=err, env=util.env_no_snap_for_external_calls())
                     nginx_proc.communicate()
                     if nginx_proc.returncode != 0:
                         # Enter recovery routine...
